@@ -13,10 +13,13 @@ logger = logging.getLogger()
 
 logger.setLevel(level=logging.DEBUG)
 logHandler = logging.StreamHandler()
-formatter = jsonlogger.JsonFormatter()
+formatter = jsonlogger.JsonFormatter("filename levelname msecs message msg")
 logHandler.setFormatter(formatter)
 logger.addHandler(logHandler)
 
+
+
+
 try:
     import picamera
 except ImportError:
